--
-- Ruefa
--
-- M@D Author:  Heady
-- M@D date: 21.06.2011
--
-- > Copyright (C) Heady - www.planet-ls.de < --
--
-- edit by modelleicher 10.04.2014
-- 

Ruefa = {};  -- changed name from Rufa to Ruefa.. finally! -modelleicher

function Ruefa.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(AnimatedVehicle, specializations);
end;

function Ruefa:load(xmlFile)
	
	local Ruefa = {};
    Ruefa.name = getXMLString(xmlFile, "vehicle.Ruefa#name");
    Ruefa.openSpeedScale = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.Ruefa#upSpeedScale"), 1);
    Ruefa.closeSpeedScale = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.Ruefa#downSpeedScale"), -Ruefa.openSpeedScale);
    if Ruefa.name ~= nil then
        self.Ruefa = Ruefa;
    end;
	self.Ruefa.active = false;
	self.RuefaActive = false;
	self.accDirection = 1;
	
	self.wheelsRotSpeedBackup = {};
	for i=1, table.getn(self.wheels) do
		self.wheelsRotSpeedBackup[i] = self.wheels[i].rotSpeed;
	end;
	
	self.Ruefa.characterTransform = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Ruefa#characterTransform"));
	self.Ruefa.characterTransformArm = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Ruefa#characterTransformArm")); -- modelleicher
	self.Ruefa.brakeLightsTransform = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Ruefa#brakeLightsTransform")); -- modelleicher
end;

function Ruefa:delete()
end;

function Ruefa:mouseEvent(posX, posY, isDown, isUp, button)
end;

function Ruefa:keyEvent(unicode, sym, modifier, isDown)
end;

function Ruefa:readStream(streamId, connection)
	self.accDirection = streamReadFloat32(streamId);	
	self.Ruefa.active = streamReadBool(streamId);
end;

function Ruefa:writeStream(streamId, connection)
	streamWriteFloat32(streamId, self.accDirection);	
	streamWriteBool(streamId, self.Ruefa.active);
end;

function Ruefa:update(dt)

	if self:getIsActiveForInput() then			
		
		if InputBinding.hasEvent(InputBinding.RuefaOnOffTrac) then
			self.Ruefa.active = not self.Ruefa.active;
		end;			

	end;
	
end;

function Ruefa:updateTick(dt)
	if self:getIsActive() then -- no need to run all this if vehicle isn't active.. -modelleicher
		if self.RuefaActive ~= self.Ruefa.active then		
			if self.Ruefa.active then
				self:playAnimation(self.Ruefa.name, self.Ruefa.openSpeedScale, self:getAnimationTime(self.Ruefa.name));
				for i=1, table.getn(self.wheels) do				
					self.wheels[i].rotSpeed = -self.wheelsRotSpeedBackup[i];
				end;
				self.accDirection = -1;
				setVisibility(self.Ruefa.brakeLightsTransform, false); -- modelleicher
			else	
				self:playAnimation(self.Ruefa.name, self.Ruefa.closeSpeedScale, self:getAnimationTime(self.Ruefa.name)); 
				for i=1, table.getn(self.wheels) do				
					self.wheels[i].rotSpeed = self.wheelsRotSpeedBackup[i];
				end;
				self.accDirection = 1;	
				setVisibility(self.Ruefa.brakeLightsTransform, true);	-- modelleicher			
			end;		
			
			RuefaMPEvent:updateSendEvent(self);	
		end;
		if self:getIsAnimationPlaying(self.Ruefa.name) then
			setVisibility(self.Ruefa.characterTransform, false);
			setVisibility(self.Ruefa.characterTransformArm, false); -- modeleicher
		else
			setVisibility(self.Ruefa.characterTransform, true);
			setVisibility(self.Ruefa.characterTransformArm, true); -- modelleicher
		end;
			
		
		self.RuefaActive = self.Ruefa.active;
	end;
end;
function Ruefa:onLeave()
	setVisibility(self.Ruefa.characterTransformArm, false); -- modelleicher
end;
function Ruefa:draw()	
	if self:getIsActiveForInput() then  -- helptext -modelleicher
		g_currentMission:addHelpButtonText(g_i18n:getText("RuefaOnOffTrac"), InputBinding.RuefaOnOffTrac);
	end;
end;


local wheelsUtilUpdateWheelsPhysics = WheelsUtil.updateWheelsPhysics;

function WheelsUtil.updateWheelsPhysics(self, dt, currentSpeed, acceleration, doHandbrake, requiredDriveMode)

	if self.accDirection ~= nil then
		acceleration = acceleration*self.accDirection;
	end;
	
	wheelsUtilUpdateWheelsPhysics(self, dt, currentSpeed, acceleration, doHandbrake, requiredDriveMode);
end;



-- includet mp event in this lua.. no need for extra file i think.. -modelleicher

RuefaMPEvent = {};
RuefaMPEvent_mt = Class(RuefaMPEvent, Event);

InitEventClass(RuefaMPEvent, "RuefaMPEvent");

function RuefaMPEvent:emptyNew()
    local self = Event:new(RuefaMPEvent_mt);
    self.className="RuefaMPEvent";
    return self;
end;

function RuefaMPEvent:new(object)
    local self = RuefaMPEvent:emptyNew()
    self.object = object;
    return self;
end;

function RuefaMPEvent:readStream(streamId, connection)
    self.object = networkGetObject(streamReadInt32(streamId));	

	self.object.accDirection = streamReadFloat32(streamId);	
	self.object.rufa.active = streamReadBool(streamId);

	if not connection:getIsServer() then
		g_server:broadcastEvent(RuefaMPEvent:new(self.object), nil, connection, self.object);
	end;

end;

function RuefaMPEvent:writeStream(streamId, connection)
    streamWriteInt32(streamId, networkGetObjectId(self.object));	
	
	streamWriteFloat32(streamId, self.object.accDirection);	
	streamWriteBool(streamId, self.object.rufa.active);
end;

function RuefaMPEvent:updateSendEvent(runSelf)	

	if g_server ~= nil then
		g_server:broadcastEvent(RuefaMPEvent:new(runSelf));
	else
		g_client:getServerConnection():sendEvent(RuefaMPEvent:new(runSelf));
	end;

end;